# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/eventrouter/v1/rule_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/eventrouter/v1/rule_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.eventrouter.v1 import rule_pb2 as yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_rule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/serverless/eventrouter/v1/rule_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x31yandex/cloud/serverless/eventrouter/v1/rule.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\'\n\x0eGetRuleRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x86\x01\n\x10ListRulesRequest\x12\x10\n\x06\x62us_id\x18\x01 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\tB\x14\n\x0c\x63ontainer_id\x12\x04\xc0\xc1\x31\x01\"i\n\x11ListRulesResponse\x12;\n\x05rules\x18\x01 \x03(\x0b\x32,.yandex.cloud.serverless.eventrouter.v1.Rule\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe5\x03\n\x11\x43reateRuleRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x92\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.serverless.eventrouter.v1.CreateRuleRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x06\x66ilter\x18\x05 \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Filter\x12H\n\x07targets\x18\x06 \x03(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.TargetB\x07\x82\xc8\x31\x03\x31-5\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x12\x43reateRuleMetadata\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"\x97\x04\n\x11UpdateRuleRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x92\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.serverless.eventrouter.v1.UpdateRuleRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x06\x66ilter\x18\x06 \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Filter\x12H\n\x07targets\x18\x07 \x03(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.TargetB\x07\x82\xc8\x31\x03\x31-5\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x12UpdateRuleMetadata\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"*\n\x11\x44\x65leteRuleRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x12\x44\x65leteRuleMetadata\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8c\x01\n\x19ListRuleOperationsRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x1aListRuleOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"*\n\x11\x45nableRuleRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x12\x45nableRuleMetadata\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x12\x44isableRuleRequest\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\",\n\x13\x44isableRuleMetadata\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xd3\x10\n\x0bRuleService\x12\x94\x01\n\x03Get\x12\x36.yandex.cloud.serverless.eventrouter.v1.GetRuleRequest\x1a,.yandex.cloud.serverless.eventrouter.v1.Rule\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/eventrouter/v1/rules/{rule_id}\x12\x9a\x01\n\x04List\x12\x38.yandex.cloud.serverless.eventrouter.v1.ListRulesRequest\x1a\x39.yandex.cloud.serverless.eventrouter.v1.ListRulesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/eventrouter/v1/rules\x12\xa6\x01\n\x06\x43reate\x12\x39.yandex.cloud.serverless.eventrouter.v1.CreateRuleRequest\x1a!.yandex.cloud.operation.Operation\">\xb2\xd2*\x1a\n\x12\x43reateRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02\x1a\"\x15/eventrouter/v1/rules:\x01*\x12\xb0\x01\n\x06Update\x12\x39.yandex.cloud.serverless.eventrouter.v1.UpdateRuleRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\x1a\n\x12UpdateRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02$2\x1f/eventrouter/v1/rules/{rule_id}:\x01*\x12\xbe\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.serverless.eventrouter.v1.DeleteRuleRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*+\n\x12\x44\x65leteRuleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/eventrouter/v1/rules/{rule_id}\x12\xc5\x01\n\x06\x45nable\x12\x39.yandex.cloud.serverless.eventrouter.v1.EnableRuleRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*+\n\x12\x45nableRuleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(\"&/eventrouter/v1/rules/{rule_id}:enable\x12\xc9\x01\n\x07\x44isable\x12:.yandex.cloud.serverless.eventrouter.v1.DisableRuleRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*,\n\x13\x44isableRuleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)\"\'/eventrouter/v1/rules/{rule_id}:disable\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/eventrouter/v1/rules/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"5/eventrouter/v1/rules/{resource_id}:setAccessBindings:\x01*\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=28/eventrouter/v1/rules/{resource_id}:updateAccessBindings:\x01*\x12\xcb\x01\n\x0eListOperations\x12\x41.yandex.cloud.serverless.eventrouter.v1.ListRuleOperationsRequest\x1a\x42.yandex.cloud.serverless.eventrouter.v1.ListRuleOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/eventrouter/v1/rules/{rule_id}/operationsB\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERRSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.rule_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERRSZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _globals['_GETRULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_GETRULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTRULESREQUEST'].oneofs_by_name['container_id']._loaded_options = None
  _globals['_LISTRULESREQUEST'].oneofs_by_name['container_id']._serialized_options = b'\300\3011\001'
  _globals['_CREATERULEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATERULEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERULEREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_CREATERULEREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATERULEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATERULEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATERULEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATERULEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATERULEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATERULEREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_CREATERULEREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\0031-5'
  _globals['_UPDATERULEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATERULEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATERULEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATERULEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATERULEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATERULEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATERULEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATERULEREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_UPDATERULEREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\0031-5'
  _globals['_UPDATERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRULEOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_ENABLERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_ENABLERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_ENABLERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_ENABLERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_DISABLERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DISABLERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_DISABLERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DISABLERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_RULESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/eventrouter/v1/rules/{rule_id}'
  _globals['_RULESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/eventrouter/v1/rules'
  _globals['_RULESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateRuleMetadata\022\004Rule\202\323\344\223\002\032\"\025/eventrouter/v1/rules:\001*'
  _globals['_RULESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateRuleMetadata\022\004Rule\202\323\344\223\002$2\037/eventrouter/v1/rules/{rule_id}:\001*'
  _globals['_RULESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteRuleMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/eventrouter/v1/rules/{rule_id}'
  _globals['_RULESERVICE'].methods_by_name['Enable']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Enable']._serialized_options = b'\262\322*+\n\022EnableRuleMetadata\022\025google.protobuf.Empty\202\323\344\223\002(\"&/eventrouter/v1/rules/{rule_id}:enable'
  _globals['_RULESERVICE'].methods_by_name['Disable']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['Disable']._serialized_options = b'\262\322*,\n\023DisableRuleMetadata\022\025google.protobuf.Empty\202\323\344\223\002)\"\'/eventrouter/v1/rules/{rule_id}:disable'
  _globals['_RULESERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/eventrouter/v1/rules/{resource_id}:listAccessBindings'
  _globals['_RULESERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002:\"5/eventrouter/v1/rules/{resource_id}:setAccessBindings:\001*'
  _globals['_RULESERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=28/eventrouter/v1/rules/{resource_id}:updateAccessBindings:\001*'
  _globals['_RULESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_RULESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002,\022*/eventrouter/v1/rules/{rule_id}/operations'
  _globals['_GETRULEREQUEST']._serialized_start=355
  _globals['_GETRULEREQUEST']._serialized_end=394
  _globals['_LISTRULESREQUEST']._serialized_start=397
  _globals['_LISTRULESREQUEST']._serialized_end=531
  _globals['_LISTRULESRESPONSE']._serialized_start=533
  _globals['_LISTRULESRESPONSE']._serialized_end=638
  _globals['_CREATERULEREQUEST']._serialized_start=641
  _globals['_CREATERULEREQUEST']._serialized_end=1126
  _globals['_CREATERULEREQUEST_LABELSENTRY']._serialized_start=1081
  _globals['_CREATERULEREQUEST_LABELSENTRY']._serialized_end=1126
  _globals['_CREATERULEMETADATA']._serialized_start=1128
  _globals['_CREATERULEMETADATA']._serialized_end=1181
  _globals['_UPDATERULEREQUEST']._serialized_start=1184
  _globals['_UPDATERULEREQUEST']._serialized_end=1719
  _globals['_UPDATERULEREQUEST_LABELSENTRY']._serialized_start=1081
  _globals['_UPDATERULEREQUEST_LABELSENTRY']._serialized_end=1126
  _globals['_UPDATERULEMETADATA']._serialized_start=1721
  _globals['_UPDATERULEMETADATA']._serialized_end=1764
  _globals['_DELETERULEREQUEST']._serialized_start=1766
  _globals['_DELETERULEREQUEST']._serialized_end=1808
  _globals['_DELETERULEMETADATA']._serialized_start=1810
  _globals['_DELETERULEMETADATA']._serialized_end=1853
  _globals['_LISTRULEOPERATIONSREQUEST']._serialized_start=1856
  _globals['_LISTRULEOPERATIONSREQUEST']._serialized_end=1996
  _globals['_LISTRULEOPERATIONSRESPONSE']._serialized_start=1998
  _globals['_LISTRULEOPERATIONSRESPONSE']._serialized_end=2106
  _globals['_ENABLERULEREQUEST']._serialized_start=2108
  _globals['_ENABLERULEREQUEST']._serialized_end=2150
  _globals['_ENABLERULEMETADATA']._serialized_start=2152
  _globals['_ENABLERULEMETADATA']._serialized_end=2195
  _globals['_DISABLERULEREQUEST']._serialized_start=2197
  _globals['_DISABLERULEREQUEST']._serialized_end=2240
  _globals['_DISABLERULEMETADATA']._serialized_start=2242
  _globals['_DISABLERULEMETADATA']._serialized_end=2286
  _globals['_RULESERVICE']._serialized_start=2289
  _globals['_RULESERVICE']._serialized_end=4420
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetArtifactRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_ID_FIELD_NUMBER: builtins.int
    artifact_id: builtins.str
    """ID of the artifact resource to return."""
    def __init__(
        self,
        *,
        artifact_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_id", b"artifact_id"]) -> None: ...

global___GetArtifactRequest = GetArtifactRequest

@typing.final
class DeleteArtifactRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_ID_FIELD_NUMBER: builtins.int
    artifact_id: builtins.str
    """ID of the artifact to delete."""
    def __init__(
        self,
        *,
        artifact_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_id", b"artifact_id"]) -> None: ...

global___DeleteArtifactRequest = DeleteArtifactRequest

@typing.final
class DeleteArtifactMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_ID_FIELD_NUMBER: builtins.int
    artifact_id: builtins.str
    """ID of the artifact to delete."""
    def __init__(
        self,
        *,
        artifact_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_id", b"artifact_id"]) -> None: ...

global___DeleteArtifactMetadata = DeleteArtifactMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.postgresql.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.postgresql.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host9__6__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql9__6__pb2
from yandex.cloud.mdb.postgresql.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2
from yandex.cloud.mdb.postgresql.v1 import backup_retention_policy_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_backup__retention__policy__pb2
from yandex.cloud.mdb.postgresql.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.postgresql.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/postgresql/v1/cluster_service.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a+yandex/cloud/mdb/postgresql/v1/backup.proto\x1a,yandex/cloud/mdb/postgresql/v1/cluster.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host10.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host10_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host11.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host11_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host12.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host12_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host13.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host13_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host14.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host14_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host15.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host15_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host16.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host16_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host17.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host17_1c.proto\x1a\x33yandex/cloud/mdb/postgresql/v1/config/host9_6.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql10.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql10_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql11.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql11_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql12.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql12_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql13.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql14.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql14_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql15.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql15_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql16.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql16_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql17.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql17_1c.proto\x1a\x39yandex/cloud/mdb/postgresql/v1/config/postgresql9_6.proto\x1a-yandex/cloud/mdb/postgresql/v1/database.proto\x1a<yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto\x1a\x30yandex/cloud/mdb/postgresql/v1/maintenance.proto\x1a)yandex/cloud/mdb/postgresql/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9b\x01\n\x19\x42\x61\x63kupRetentionPolicySpec\x12\x19\n\x0bpolicy_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x04\x63ron\x18\x02 \x01(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.CronTab\x12\x17\n\x0fretain_for_days\x18\x03 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\xc8\x07\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12N\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x45\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12J\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\x12\x42\n\nuser_specs\x18\x08 \x03(\x0b\x32(.yandex.cloud.mdb.postgresql.v1.UserSpecB\x04\xe8\xc7\x31\x01\x12\x42\n\nhost_specs\x18\t \x03(\x0b\x32(.yandex.cloud.mdb.postgresql.v1.HostSpecB\x04\xe8\xc7\x31\x01\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\r \x03(\t\x12M\n\x12maintenance_window\x18\x0e \x01(\x0b\x32\x31.yandex.cloud.mdb.postgresql.v1.MaintenanceWindow\x12U\n\x12retention_policies\x18\x0f \x03(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.BackupRetentionPolicySpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xdf\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12?\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12M\n\x12maintenance_window\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.mdb.postgresql.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12\x1c\n\nnetwork_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\n\x10\x0b\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\">\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xed\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0etime_inclusive\x18\x03 \x01(\x08\x12,\n\x04name\x18\x04 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x06 \x03(\x0b\x32\x41.yandex.cloud.mdb.postgresql.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12N\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x45\n\x0b\x63onfig_spec\x18\x08 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12\x44\n\nhost_specs\x18\t \x03(\x0b\x32(.yandex.cloud.mdb.postgresql.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"]\n\x1bStartClusterFailoverRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\thost_name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=253\"2\n\x1cStartClusterFailoverMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xcf\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12j\n\x0freschedule_type\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.postgresql.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\xb3\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x07message\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xae\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12X\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x42.yandex.cloud.mdb.postgresql.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\"G\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06POOLER\x10\x02\"k\n\x17ListClusterLogsResponse\x12\x37\n\x04logs\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.postgresql.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x0fStreamLogRecord\x12\x39\n\x06record\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x91\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12Z\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x44.yandex.cloud.mdb.postgresql.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"G\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06POOLER\x10\x02\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1aListClusterBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.postgresql.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x18ListClusterHostsResponse\x12\x33\n\x05hosts\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.postgresql.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x01\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\nhost_specs\x18\x02 \x03(\x0b\x32(.yandex.cloud.mdb.postgresql.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x90\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Q\n\x11update_host_specs\x18\x02 \x03(\x0b\x32..yandex.cloud.mdb.postgresql.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x84\x02\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12replication_source\x18\x02 \x01(\t\x12-\n\x08priority\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x0b\x63onfig_spec\x18\x04 \x01(\x0b\x32..yandex.cloud.mdb.postgresql.v1.ConfigHostSpec\x12/\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\"\xec\x01\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12\x1a\n\x12replication_source\x18\x04 \x01(\t\x12-\n\x08priority\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32..yandex.cloud.mdb.postgresql.v1.ConfigHostSpec\"\x9c\x14\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12q\n\x15postgresql_config_9_6\x18\x02 \x01(\x0b\x32:.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig9_6H\x00R\x14postgresqlConfig_9_6\x12w\n\x17postgresql_config_10_1c\x18\n \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig10_1CH\x00R\x16postgresqlConfig_10_1c\x12n\n\x14postgresql_config_10\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig10H\x00R\x13postgresqlConfig_10\x12n\n\x14postgresql_config_11\x18\x07 \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig11H\x00R\x13postgresqlConfig_11\x12w\n\x17postgresql_config_11_1c\x18\r \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig11_1CH\x00R\x16postgresqlConfig_11_1c\x12n\n\x14postgresql_config_12\x18\x0b \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig12H\x00R\x13postgresqlConfig_12\x12w\n\x17postgresql_config_12_1c\x18\x0e \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig12_1CH\x00R\x16postgresqlConfig_12_1c\x12n\n\x14postgresql_config_13\x18\x0f \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13H\x00R\x13postgresqlConfig_13\x12w\n\x17postgresql_config_13_1c\x18\x12 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig13_1CH\x00R\x16postgresqlConfig_13_1c\x12n\n\x14postgresql_config_14\x18\x10 \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig14H\x00R\x13postgresqlConfig_14\x12w\n\x17postgresql_config_14_1c\x18\x13 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig14_1CH\x00R\x16postgresqlConfig_14_1c\x12n\n\x14postgresql_config_15\x18\x15 \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15H\x00R\x13postgresqlConfig_15\x12w\n\x17postgresql_config_15_1c\x18\x16 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1CH\x00R\x16postgresqlConfig_15_1c\x12n\n\x14postgresql_config_16\x18\x18 \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig16H\x00R\x13postgresqlConfig_16\x12w\n\x17postgresql_config_16_1c\x18\x19 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig16_1CH\x00R\x16postgresqlConfig_16_1c\x12n\n\x14postgresql_config_17\x18\x1b \x01(\x0b\x32\x39.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig17H\x00R\x13postgresqlConfig_17\x12w\n\x17postgresql_config_17_1c\x18\x1c \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig17_1CH\x00R\x16postgresqlConfig_17_1c\x12M\n\rpooler_config\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.ConnectionPoolerConfig\x12<\n\tresources\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Resources\x12\x30\n\x0c\x61utofailover\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x08 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-60\x12\x36\n\x06\x61\x63\x63\x65ss\x18\t \x01(\x0b\x32&.yandex.cloud.mdb.postgresql.v1.Access\x12W\n\x17performance_diagnostics\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.PerformanceDiagnostics\x12R\n\x15\x64isk_size_autoscaling\x18\x17 \x01(\x0b\x32\x33.yandex.cloud.mdb.postgresql.v1.DiskSizeAutoscalingB\x13\n\x11postgresql_configJ\x04\x08\x14\x10\x15J\x04\x08\x1a\x10\x1b\"\xe8\x10\n\x0e\x43onfigHostSpec\x12y\n\x15postgresql_config_9_6\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig9_6H\x00R\x18postgresqlHostConfig_9_6\x12\x7f\n\x17postgresql_config_10_1c\x18\x04 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10_1CH\x00R\x1apostgresqlHostConfig_10_1c\x12v\n\x14postgresql_config_10\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10H\x00R\x17postgresqlHostConfig_10\x12v\n\x14postgresql_config_11\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11H\x00R\x17postgresqlHostConfig_11\x12\x7f\n\x17postgresql_config_11_1c\x18\x06 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11_1CH\x00R\x1apostgresqlHostConfig_11_1c\x12v\n\x14postgresql_config_12\x18\x05 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12H\x00R\x17postgresqlHostConfig_12\x12\x7f\n\x17postgresql_config_12_1c\x18\x07 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12_1CH\x00R\x1apostgresqlHostConfig_12_1c\x12v\n\x14postgresql_config_13\x18\x08 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13H\x00R\x17postgresqlHostConfig_13\x12\x7f\n\x17postgresql_config_13_1c\x18\n \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13_1CH\x00R\x1apostgresqlHostConfig_13_1c\x12v\n\x14postgresql_config_14\x18\t \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14H\x00R\x17postgresqlHostConfig_14\x12\x7f\n\x17postgresql_config_14_1c\x18\x0b \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14_1CH\x00R\x1apostgresqlHostConfig_14_1c\x12v\n\x14postgresql_config_15\x18\x0c \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15H\x00R\x17postgresqlHostConfig_15\x12\x7f\n\x17postgresql_config_15_1c\x18\r \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15_1CH\x00R\x1apostgresqlHostConfig_15_1c\x12v\n\x14postgresql_config_16\x18\x0e \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16H\x00R\x17postgresqlHostConfig_16\x12\x7f\n\x17postgresql_config_16_1c\x18\x0f \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1CH\x00R\x1apostgresqlHostConfig_16_1c\x12v\n\x14postgresql_config_17\x18\x10 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17H\x00R\x17postgresqlHostConfig_17\x12\x7f\n\x17postgresql_config_17_1c\x18\x11 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17_1CH\x00R\x1apostgresqlHostConfig_17_1cB\x13\n\x11postgresql_config2\xb7\x1f\n\x0e\x43lusterService\x12\x97\x01\n\x03Get\x12\x31.yandex.cloud.mdb.postgresql.v1.GetClusterRequest\x1a\'.yandex.cloud.mdb.postgresql.v1.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-postgresql/v1/clusters/{cluster_id}\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.postgresql.v1.ListClustersRequest\x1a\x34.yandex.cloud.mdb.postgresql.v1.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-postgresql/v1/clusters\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.postgresql.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02$\"\x1f/managed-postgresql/v1/clusters:\x01*\x12\xbe\x01\n\x06Update\x12\x34.yandex.cloud.mdb.postgresql.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\x32,/managed-postgresql/v1/clusters/{cluster_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.postgresql.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/managed-postgresql/v1/clusters/{cluster_id}\x12\xbe\x01\n\x05Start\x12\x33.yandex.cloud.mdb.postgresql.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\"2/managed-postgresql/v1/clusters/{cluster_id}:start\x12\xba\x01\n\x04Stop\x12\x32.yandex.cloud.mdb.postgresql.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-postgresql/v1/clusters/{cluster_id}:stop\x12\xbd\x01\n\x04Move\x12\x32.yandex.cloud.mdb.postgresql.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x36\"1/managed-postgresql/v1/clusters/{cluster_id}:move:\x01*\x12\xc2\x01\n\x06\x42\x61\x63kup\x12\x34.yandex.cloud.mdb.postgresql.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x35\"3/managed-postgresql/v1/clusters/{cluster_id}:backup\x12\xbc\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.postgresql.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/managed-postgresql/v1/clusters:restore:\x01*\x12\xf3\x01\n\x15RescheduleMaintenance\x12<.yandex.cloud.mdb.postgresql.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02G\"B/managed-postgresql/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xe1\x01\n\rStartFailover\x12;.yandex.cloud.mdb.postgresql.v1.StartClusterFailoverRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*\'\n\x1cStartClusterFailoverMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02?\":/managed-postgresql/v1/clusters/{cluster_id}:startFailover:\x01*\x12\xb6\x01\n\x08ListLogs\x12\x36.yandex.cloud.mdb.postgresql.v1.ListClusterLogsRequest\x1a\x37.yandex.cloud.mdb.postgresql.v1.ListClusterLogsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-postgresql/v1/clusters/{cluster_id}:logs\x12\xbb\x01\n\nStreamLogs\x12\x38.yandex.cloud.mdb.postgresql.v1.StreamClusterLogsRequest\x1a/.yandex.cloud.mdb.postgresql.v1.StreamLogRecord\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-postgresql/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.mdb.postgresql.v1.ListClusterOperationsRequest\x1a=.yandex.cloud.mdb.postgresql.v1.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-postgresql/v1/clusters/{cluster_id}/operations\x12\xc2\x01\n\x0bListBackups\x12\x39.yandex.cloud.mdb.postgresql.v1.ListClusterBackupsRequest\x1a:.yandex.cloud.mdb.postgresql.v1.ListClusterBackupsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-postgresql/v1/clusters/{cluster_id}/backups\x12\xba\x01\n\tListHosts\x12\x37.yandex.cloud.mdb.postgresql.v1.ListClusterHostsRequest\x1a\x38.yandex.cloud.mdb.postgresql.v1.ListClusterHostsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-postgresql/v1/clusters/{cluster_id}/hosts\x12\xe4\x01\n\x08\x41\x64\x64Hosts\x12\x36.yandex.cloud.mdb.postgresql.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xee\x01\n\x0b\x44\x65leteHosts\x12\x39.yandex.cloud.mdb.postgresql.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xee\x01\n\x0bUpdateHosts\x12\x39.yandex.cloud.mdb.postgresql.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*Bs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BACKUPRETENTIONPOLICYSPEC'].fields_by_name['policy_name']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICYSPEC'].fields_by_name['policy_name']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['database_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['database_specs']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['host_name']._loaded_options = None
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['host_name']._serialized_options = b'\212\3101\005<=253'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._loaded_options = None
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CONFIGSPEC'].fields_by_name['backup_retain_period_days']._loaded_options = None
  _globals['_CONFIGSPEC'].fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0047-60'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/managed-postgresql/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-postgresql/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002$\"\037/managed-postgresql/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00212,/managed-postgresql/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/managed-postgresql/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0024\"2/managed-postgresql/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-postgresql/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0026\"1/managed-postgresql/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0025\"3/managed-postgresql/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/managed-postgresql/v1/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002G\"B/managed-postgresql/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['StartFailover']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StartFailover']._serialized_options = b'\262\322*\'\n\034StartClusterFailoverMetadata\022\007Cluster\202\323\344\223\002?\":/managed-postgresql/v1/clusters/{cluster_id}:startFailover:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0023\0221/managed-postgresql/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\002:\0228/managed-postgresql/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/managed-postgresql/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0026\0224/managed-postgresql/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0024\0222/managed-postgresql/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-postgresql/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=2564
  _globals['_GETCLUSTERREQUEST']._serialized_end=2617
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=2620
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=2764
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=2766
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=2872
  _globals['_BACKUPRETENTIONPOLICYSPEC']._serialized_start=2875
  _globals['_BACKUPRETENTIONPOLICYSPEC']._serialized_end=3030
  _globals['_CREATECLUSTERREQUEST']._serialized_start=3033
  _globals['_CREATECLUSTERREQUEST']._serialized_end=4001
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=3956
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=4001
  _globals['_CREATECLUSTERMETADATA']._serialized_start=4003
  _globals['_CREATECLUSTERMETADATA']._serialized_end=4046
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=4049
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=4656
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=3956
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=4001
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=4658
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=4701
  _globals['_DELETECLUSTERREQUEST']._serialized_start=4703
  _globals['_DELETECLUSTERREQUEST']._serialized_end=4759
  _globals['_DELETECLUSTERMETADATA']._serialized_start=4761
  _globals['_DELETECLUSTERMETADATA']._serialized_end=4804
  _globals['_STARTCLUSTERREQUEST']._serialized_start=4806
  _globals['_STARTCLUSTERREQUEST']._serialized_end=4861
  _globals['_STARTCLUSTERMETADATA']._serialized_start=4863
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4905
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4907
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4961
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4963
  _globals['_STOPCLUSTERMETADATA']._serialized_end=5004
  _globals['_MOVECLUSTERREQUEST']._serialized_start=5006
  _globals['_MOVECLUSTERREQUEST']._serialized_end=5105
  _globals['_MOVECLUSTERMETADATA']._serialized_start=5107
  _globals['_MOVECLUSTERMETADATA']._serialized_end=5205
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=5207
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=5263
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=5265
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=5327
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=5330
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=6079
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=3956
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=4001
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=6081
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=6144
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_start=6146
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_end=6239
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_start=6241
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_end=6291
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=6294
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=6629
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=6519
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=6629
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=6631
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=6739
  _globals['_LOGRECORD']._serialized_start=6742
  _globals['_LOGRECORD']._serialized_end=6921
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=6875
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=6921
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=6924
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=7354
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=7283
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=7354
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=7356
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=7463
  _globals['_STREAMLOGRECORD']._serialized_start=7465
  _globals['_STREAMLOGRECORD']._serialized_end=7568
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=7571
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=7972
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=7283
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=7354
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=7974
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=8100
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=8102
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=8213
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=8215
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=8338
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=8340
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=8450
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=8452
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=8573
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=8575
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=8679
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=8682
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=8810
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=8812
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=8877
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=8879
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=8977
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=8979
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=9047
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=9050
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=9194
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=9196
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=9264
  _globals['_UPDATEHOSTSPEC']._serialized_start=9267
  _globals['_UPDATEHOSTSPEC']._serialized_end=9527
  _globals['_HOSTSPEC']._serialized_start=9530
  _globals['_HOSTSPEC']._serialized_end=9766
  _globals['_CONFIGSPEC']._serialized_start=9769
  _globals['_CONFIGSPEC']._serialized_end=12357
  _globals['_CONFIGHOSTSPEC']._serialized_start=12360
  _globals['_CONFIGHOSTSPEC']._serialized_end=14512
  _globals['_CLUSTERSERVICE']._serialized_start=14515
  _globals['_CLUSTERSERVICE']._serialized_end=18538
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/vision/v1/vision_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/vision/v1/vision_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v1 import text_detection_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_text__detection__pb2
from yandex.cloud.ai.vision.v1 import classification_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_classification__pb2
from yandex.cloud.ai.vision.v1 import face_detection_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_face__detection__pb2
from yandex.cloud.ai.vision.v1 import image_copy_search_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_image__copy__search__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/vision/v1/vision_service.proto\x12\x19yandex.cloud.ai.vision.v1\x1a.yandex/cloud/ai/vision/v1/text_detection.proto\x1a.yandex/cloud/ai/vision/v1/classification.proto\x1a.yandex/cloud/ai/vision/v1/face_detection.proto\x1a\x31yandex/cloud/ai/vision/v1/image_copy_search.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/rpc/status.proto\"z\n\x13\x42\x61tchAnalyzeRequest\x12\x46\n\ranalyze_specs\x18\x01 \x03(\x0b\x32&.yandex.cloud.ai.vision.v1.AnalyzeSpecB\x07\x82\xc8\x31\x03\x31-8\x12\x1b\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xc5\x01\n\x0b\x41nalyzeSpec\x12!\n\x07\x63ontent\x18\x01 \x01(\x0c\x42\x0e\x8a\xc8\x31\n<=10485760H\x00\x12 \n\tsignature\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=16384H\x00\x12=\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32\".yandex.cloud.ai.vision.v1.FeatureB\x07\x82\xc8\x31\x03\x31-8\x12\x1c\n\tmime_type\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=255B\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\"\xec\x02\n\x07\x46\x65\x61ture\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.ai.vision.v1.Feature.Type\x12W\n\x15\x63lassification_config\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.ai.vision.v1.FeatureClassificationConfigH\x00\x12V\n\x15text_detection_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.vision.v1.FeatureTextDetectionConfigH\x00\"o\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eTEXT_DETECTION\x10\x01\x12\x12\n\x0e\x43LASSIFICATION\x10\x02\x12\x12\n\x0e\x46\x41\x43\x45_DETECTION\x10\x03\x12\x15\n\x11IMAGE_COPY_SEARCH\x10\x04\x42\x08\n\x06\x63onfig\"7\n\x1b\x46\x65\x61tureClassificationConfig\x12\x18\n\x05model\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\"]\n\x1a\x46\x65\x61tureTextDetectionConfig\x12&\n\x0elanguage_codes\x18\x01 \x03(\tB\x0e\x82\xc8\x31\x03\x31-8\x8a\xc8\x31\x03<=3\x12\x17\n\x05model\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"Q\n\x14\x42\x61tchAnalyzeResponse\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.yandex.cloud.ai.vision.v1.AnalyzeResult\"m\n\rAnalyzeResult\x12\x39\n\x07results\x18\x02 \x03(\x0b\x32(.yandex.cloud.ai.vision.v1.FeatureResult\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\"\xe0\x02\n\rFeatureResult\x12\x43\n\x0etext_detection\x18\x02 \x01(\x0b\x32).yandex.cloud.ai.vision.v1.TextAnnotationH\x00\x12\x44\n\x0e\x63lassification\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.vision.v1.ClassAnnotationH\x00\x12\x43\n\x0e\x66\x61\x63\x65_detection\x18\x04 \x01(\x0b\x32).yandex.cloud.ai.vision.v1.FaceAnnotationH\x00\x12Q\n\x11image_copy_search\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.ai.vision.v1.ImageCopySearchAnnotationH\x00\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.google.rpc.StatusB\t\n\x07\x66\x65\x61ture2\xa5\x01\n\rVisionService\x12\x93\x01\n\x0c\x42\x61tchAnalyze\x12..yandex.cloud.ai.vision.v1.BatchAnalyzeRequest\x1a/.yandex.cloud.ai.vision.v1.BatchAnalyzeResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/vision/v1/batchAnalyze:\x01*Be\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v1.vision_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision'
  _globals['_BATCHANALYZEREQUEST'].fields_by_name['analyze_specs']._loaded_options = None
  _globals['_BATCHANALYZEREQUEST'].fields_by_name['analyze_specs']._serialized_options = b'\202\3101\0031-8'
  _globals['_BATCHANALYZEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_BATCHANALYZEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ANALYZESPEC'].oneofs_by_name['source']._loaded_options = None
  _globals['_ANALYZESPEC'].oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _globals['_ANALYZESPEC'].fields_by_name['content']._loaded_options = None
  _globals['_ANALYZESPEC'].fields_by_name['content']._serialized_options = b'\212\3101\n<=10485760'
  _globals['_ANALYZESPEC'].fields_by_name['signature']._loaded_options = None
  _globals['_ANALYZESPEC'].fields_by_name['signature']._serialized_options = b'\212\3101\007<=16384'
  _globals['_ANALYZESPEC'].fields_by_name['features']._loaded_options = None
  _globals['_ANALYZESPEC'].fields_by_name['features']._serialized_options = b'\202\3101\0031-8'
  _globals['_ANALYZESPEC'].fields_by_name['mime_type']._loaded_options = None
  _globals['_ANALYZESPEC'].fields_by_name['mime_type']._serialized_options = b'\212\3101\005<=255'
  _globals['_FEATURECLASSIFICATIONCONFIG'].fields_by_name['model']._loaded_options = None
  _globals['_FEATURECLASSIFICATIONCONFIG'].fields_by_name['model']._serialized_options = b'\212\3101\005<=256'
  _globals['_FEATURETEXTDETECTIONCONFIG'].fields_by_name['language_codes']._loaded_options = None
  _globals['_FEATURETEXTDETECTIONCONFIG'].fields_by_name['language_codes']._serialized_options = b'\202\3101\0031-8\212\3101\003<=3'
  _globals['_FEATURETEXTDETECTIONCONFIG'].fields_by_name['model']._loaded_options = None
  _globals['_FEATURETEXTDETECTIONCONFIG'].fields_by_name['model']._serialized_options = b'\212\3101\004<=50'
  _globals['_VISIONSERVICE'].methods_by_name['BatchAnalyze']._loaded_options = None
  _globals['_VISIONSERVICE'].methods_by_name['BatchAnalyze']._serialized_options = b'\202\323\344\223\002\034\"\027/vision/v1/batchAnalyze:\001*'
  _globals['_BATCHANALYZEREQUEST']._serialized_start=358
  _globals['_BATCHANALYZEREQUEST']._serialized_end=480
  _globals['_ANALYZESPEC']._serialized_start=483
  _globals['_ANALYZESPEC']._serialized_end=680
  _globals['_FEATURE']._serialized_start=683
  _globals['_FEATURE']._serialized_end=1047
  _globals['_FEATURE_TYPE']._serialized_start=926
  _globals['_FEATURE_TYPE']._serialized_end=1037
  _globals['_FEATURECLASSIFICATIONCONFIG']._serialized_start=1049
  _globals['_FEATURECLASSIFICATIONCONFIG']._serialized_end=1104
  _globals['_FEATURETEXTDETECTIONCONFIG']._serialized_start=1106
  _globals['_FEATURETEXTDETECTIONCONFIG']._serialized_end=1199
  _globals['_BATCHANALYZERESPONSE']._serialized_start=1201
  _globals['_BATCHANALYZERESPONSE']._serialized_end=1282
  _globals['_ANALYZERESULT']._serialized_start=1284
  _globals['_ANALYZERESULT']._serialized_end=1393
  _globals['_FEATURERESULT']._serialized_start=1396
  _globals['_FEATURERESULT']._serialized_end=1748
  _globals['_VISIONSERVICE']._serialized_start=1751
  _globals['_VISIONSERVICE']._serialized_end=1916
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.awscompatibility.access_key_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetAccessKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the AccessKey resource to return.
    To get the access key ID, use a [AccessKeyService.List] request.
    """
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id"]) -> None: ...

global___GetAccessKeyRequest = GetAccessKeyRequest

@typing.final
class ListAccessKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to list access keys for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    use current subject identity if this not set
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListAccessKeysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListAccessKeysResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListAccessKeysRequest = ListAccessKeysRequest

@typing.final
class ListAccessKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListAccessKeysRequest.page_size], use
    the [next_page_token] as the value
    for the [ListAccessKeysRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def access_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey]:
        """List of access keys."""

    def __init__(
        self,
        *,
        access_keys: collections.abc.Iterable[yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_keys", b"access_keys", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAccessKeysResponse = ListAccessKeysResponse

@typing.final
class CreateAccessKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to create an access key for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    use current subject identity if this not set
    """
    description: builtins.str
    """Description of the access key."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateAccessKeyRequest = CreateAccessKeyRequest

@typing.final
class CreateAccessKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    secret: builtins.str
    """Secret access key.
    The key is AWS compatible.
    """
    @property
    def access_key(self) -> yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey:
        """AccessKey resource."""

    def __init__(
        self,
        *,
        access_key: yandex.cloud.iam.v1.awscompatibility.access_key_pb2.AccessKey | None = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_key", b"access_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_key", b"access_key", "secret", b"secret"]) -> None: ...

global___CreateAccessKeyResponse = CreateAccessKeyResponse

@typing.final
class UpdateAccessKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the AccessKey resource to update.
    To get the access key ID, use a [AccessKeyService.List] request.
    """
    description: builtins.str
    """Description of the access key."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Accesskey resource are going to be updated."""

    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id", "description", b"description", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAccessKeyRequest = UpdateAccessKeyRequest

@typing.final
class UpdateAccessKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the AccessKey resource that is being updated."""
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id"]) -> None: ...

global___UpdateAccessKeyMetadata = UpdateAccessKeyMetadata

@typing.final
class DeleteAccessKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the access key to delete.
    To get the access key ID, use a [AccessKeyService.List] request.
    """
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id"]) -> None: ...

global___DeleteAccessKeyRequest = DeleteAccessKeyRequest

@typing.final
class DeleteAccessKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the access key that is being deleted."""
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id"]) -> None: ...

global___DeleteAccessKeyMetadata = DeleteAccessKeyMetadata

@typing.final
class ListAccessKeyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the key to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListAccessKeyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListAccessKeyOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAccessKeyOperationsRequest = ListAccessKeyOperationsRequest

@typing.final
class ListAccessKeyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListAccessKeyOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListAccessKeyOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified access key."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListAccessKeyOperationsResponse = ListAccessKeyOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.stt.v2.stt_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SttServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    LongRunningRecognize: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v2.stt_service_pb2.LongRunningRecognitionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    StreamingRecognize: grpc.StreamStreamMultiCallable[
        yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionRequest,
        yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionResponse,
    ]

class SttServiceAsyncStub:
    LongRunningRecognize: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.stt.v2.stt_service_pb2.LongRunningRecognitionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    StreamingRecognize: grpc.aio.StreamStreamMultiCallable[
        yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionRequest,
        yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionResponse,
    ]

class SttServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def LongRunningRecognize(
        self,
        request: yandex.cloud.ai.stt.v2.stt_service_pb2.LongRunningRecognitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def StreamingRecognize(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionRequest],
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionResponse], collections.abc.AsyncIterator[yandex.cloud.ai.stt.v2.stt_service_pb2.StreamingRecognitionResponse]]: ...

def add_SttServiceServicer_to_server(servicer: SttServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
